@@ -26,11 +26,6 @@ from oauth2client import tools
 from oauth2client import file 
 from googleapiclient.errors import HttpError
 
-try:
-	import argparse
-	flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args()
-except ImportError:
-	flags = None
 
 def read_connection_data_from_external_file(filepath, separator="="):
 	"""Reads SQL server connection information from an external file.
@@ -477,9 +472,9 @@ def insert_file_into_folder(drive_service, folder_id, file_id):
 	"""
 	drive_service.files().update(fileId=file_id, addParents=folder_id, fields='id, parents').execute()
 
-
-def main():
-	pass
-
 if __name__ == '__main__':
-	main()
\ No newline at end of file
+	try:
+		import argparse
+		flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args()
+	except ImportError:
+		flags = None
\ No newline at end of file
